/**
 * Calculates the maturity amount of a Public Provident Fund (PPF).
 * @param annualInvestment - The amount invested annually.
 * @param annualInterestRate - The annual interest rate (in percentage).
 * @param totalYears - The total duration of the PPF account in years (usually 15 years).
 * @returns The maturity amount of the PPF account.
 * @throws Error if any parameter is invalid.
 */
export declare function calculatePPF(annualInvestment: number, annualInterestRate: number, totalYears?: number): number;
/**
 * Calculates the maturity amount of the Employee Provident Fund (EPF).
 * @param basicSalary - The basic salary of the employee.
 * @param employeeContributionRate - The percentage of the basic salary contributed by the employee (usually 12%).
 * @param employerContributionRate - The percentage of the basic salary contributed by the employer (usually 3.67% for EPF).
 * @param annualInterestRate - The annual interest rate for EPF (in percentage).
 * @param totalYears - The total number of years of service.
 * @returns The maturity amount of the EPF account.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateEPF(basicSalary: number, employeeContributionRate: number | undefined, employerContributionRate: number | undefined, annualInterestRate: number | undefined, totalYears: number): number;
/**
 * Calculates the HRA (House Rent Allowance) exemption.
 * @param basicSalary - The basic salary of the employee.
 * @param hraReceived - The HRA received from the employer.
 * @param rentPaid - The actual rent paid by the employee.
 * @param isMetroCity - Boolean indicating if the employee lives in a metro city (e.g., Delhi, Mumbai, Kolkata, Chennai).
 * @returns The HRA exemption amount.
 * @throws Error if any parameter is invalid.
 */
export declare function calculateHRAExemption(basicSalary: number, hraReceived: number, rentPaid: number, isMetroCity: boolean): number;
/**
 * Calculates the income tax based on the taxable income using the old tax regime.
 * @param taxableIncome - The taxable income of the individual.
 * @returns The calculated income tax.
 * @throws Error if the taxable income is invalid.
 */
export declare function calculateIncomeTax(taxableIncome: number): number;
interface TaxCalculation {
    oldRegimeTax: number;
    newRegimeTax: number;
    recommendedRegime: string;
}
/**
 * Calculates the tax liability under both old and new regimes and recommends the better option.
 * @param grossIncome - The gross income before deductions.
 * @param hraExemption - The HRA exemption amount (if applicable).
 * @param section80CDeduction - The total deduction under Section 80C.
 * @param section80DDeduction - The total deduction under Section 80D.
 * @param otherDeductions - Other eligible deductions (e.g., home loan interest).
 * @returns An object containing tax liabilities under both regimes and the recommended regime.
 */
export declare function calculateAdvancedIncomeTax(grossIncome: number, hraExemption?: number, section80CDeduction?: number, section80DDeduction?: number, otherDeductions?: number): TaxCalculation;
export {};
